@@ -145,12 +145,6 @@ def stream_sqlite(sqlite_chunks):
                         )
                     )
 
-            def yield_interior_table_cells(page_bytes, pointers):
-                for pointer in pointers:
-                    cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
-                    page_number, =  unsigned_long.unpack(cell_num_reader(4))
-                    yield page_number
-
             def get_master_table(master_cells):
                 def schema(cur, table_name, sql):
                     cur.execute(sql)
@@ -164,12 +158,13 @@ def stream_sqlite(sqlite_chunks):
 
                     return tuple(
                         (
-                            cell[1],                        # table name
-                            schema(cur, cell[1], cell[4]),  # table info
-                            cell[3],                        # root page
+                            cell[0],                                                        # table or index
+                            cell[1],                                                        # table name
+                            schema(cur, cell[1], cell[4]) if cell[0] == 'table' else None,  # table info
+                            cell[3],                                                        # root page
                         )
                         for cell in master_cells
-                        if cell[0] == 'table'
+                        if cell[0] in ('table', 'index')
                     )
 
             page_type = page_reader(1)
@@ -183,9 +178,12 @@ def stream_sqlite(sqlite_chunks):
             pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
 
             if page_type == LEAF_TABLE and table_name == 'sqlite_schema':
-                for table_name, table_info, root_page in get_master_table(yield_leaf_table_cells(page_bytes, pointers)):
-                    master_table[table_name] = table_info
-                    yield from process_if_buffered_or_remember(partial(process_table_page, table_name), root_page)
+                for table_or_index, table_name, table_info, root_page in get_master_table(yield_leaf_table_cells(page_bytes, pointers)):
+                    if table_or_index == 'table':
+                        master_table[table_name] = table_info
+                        yield from process_if_buffered_or_remember(partial(process_table_page, table_name), root_page)
+                    else:
+                        yield from process_if_buffered_or_remember(partial(process_index_page, table_name), root_page)
 
             elif page_type == LEAF_TABLE:
                 table_info = master_table[table_name]
@@ -198,15 +196,41 @@ def stream_sqlite(sqlite_chunks):
                 )
 
             elif page_type == INTERIOR_TABLE:
-                for page_num in yield_interior_table_cells(page_bytes, pointers):
+                for pointer in pointers:
+                    cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
+                    page_number, =  unsigned_long.unpack(cell_num_reader(4))
                     yield from process_if_buffered_or_remember(
-                        partial(process_table_page, table_name), page_num)
+                        partial(process_table_page, table_name), page_number)
+
                 yield from process_if_buffered_or_remember(
                     partial(process_table_page, table_name), right_most_pointer)
 
             else:
                 raise ValueError('Unhandled table page type in SQLite stream')
 
+        def process_index_page(table_name, page_bytes, page_reader):
+            page_type = page_reader(1)
+            if page_type == LEAF_INDEX:
+                return
+
+            first_free_block, num_cells, cell_content_start, num_frag_free = \
+                table_header.unpack(page_reader(7))
+            cell_content_start = 65536 if cell_content_start == 0 else cell_content_start
+            right_most_pointer, = \
+                unsigned_long.unpack(page_reader(4)) if page_type == INTERIOR_INDEX else \
+                (None,)
+
+            pointers = unpack('>{}H'.format(num_cells), page_reader(num_cells * 2))
+
+            for pointer in pointers:
+                cell_num_reader, cell_varint_reader = get_chunk_readers(page_bytes, pointer)
+                page_num, =  unsigned_long.unpack(cell_num_reader(4))
+                yield from process_if_buffered_or_remember(
+                    partial(process_index_page, table_name), page_num)
+
+            yield from process_if_buffered_or_remember(
+                partial(process_index_page, table_name), right_most_pointer)
+
         def process_freelist_trunk_page(page_bytes, page_reader):
             next_trunk, num_leaves = freelist_trunk_header.unpack(page_reader(8))
             leaf_pages = unpack('>{}L'.format(num_leaves), page_reader(num_leaves * 4))
